@@ -11,7 +11,6 @@ use Net::RDAP::EPPStatusMap;
 use Pod::Usage;
 use Term::ANSIColor;
 use Text::Wrap;
-use Time::HiRes qw(time);
 use URI;
 use constant {
     # see RFC 6350, Section 6.3.1.
@@ -28,7 +27,7 @@ use strict;
 
 $SIG{__DIE__} = sub { Carp::confess(@_) };
 
-$VERSION = 0.6;
+$VERSION = 0.7;
 
 #
 # global arg variables (note: nopager is now ignored)
@@ -531,42 +530,45 @@ to be used when accessing the specified resource.
 
 To install, run:
 
-    perl Makefile.PL
-    make
-    sudo make install
+	cpanm --sudo App::rdapper
 
-You may need to manually install one or more of the dependencies
-(listed below), if they are not already installed, using C<cpanm> or
-your operating system vendor's packages.
+=head1 RUNNING VIA DOCKER
+
+The L<git repository|https://github.com/gbxyz/rdapper> contains a C<Dockerfile>
+that can be used to build an image on your local system.
+
+Alternatively, you can pull the L<image from Docker Hub|https://hub.docker.com/repository/docker/gbxyz/rdapper/general>:
+
+	$ docker pull gbxyz/rdapper
+
+	$ docker run -it gbxyz/rdapper --help
 
 =head1 DEPENDENCIES
 
-C<rdapper> uses the following modules, some of which may already be
-installed:
+In addition to L<Net::RDAP>, C<rdapper> uses the following modules, some
+of which may already be installed:
 
 =over
 
+=item * L<Carp>
+
 =item * L<Getopt::Long>
 
 =item * L<List::MoreUtils>
 
-=item * L<Net::ASN>
-
-=item * L<Net::DNS::Domain>
-
-=item * L<Net::IP>
-
-=item * L<Net::RDAP> (obviously)
+=item * L<Pod::Usage>
 
 =item * L<Term::ANSIColor>
 
 =item * L<Text::Wrap>
 
+=item * L<URI>
+
 =back
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2022 CentralNic Ltd. All rights reserved. This program is
+Copyright (c) 2023 CentralNic Ltd. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
